## gguf-pack

install it via pip/pip3 by:
```
pip install gguf-pack
```

download the pack by:
```
py -m gguf_pack
```
if no py command, use python/python3

### run the pack
- locate the .bat file in the main directory and run it
- this is a developmental pack for code editing purpose

![screenshot](https://raw.githubusercontent.com/calcuis/comfy/master/gguf-pack.png)

metadata inside the sample picture above (drag it to the activated browser for workflow)

### * major difference between gguf-pack and comfy
- gguf is a core node in gguf-pack
- gguf is a custom node in comfy

### reference
- ui-codebase: comfy
- base: llama.cpp
- gguf-node
- gguf-connector